@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_Qml_src_qml_qtqml_config_p_h_H
+#define QT_FEATURES_Qml_src_qml_qtqml_config_p_h_H
+
 #define QT_FEATURE_qml_jit -1
 
 #define QT_FEATURE_qml_profiler 1
@@ -16,6 +19,8 @@
 
 #define QT_FEATURE_qml_xmllistmodel 1
 
+#define QT_FEATURE_qml_type_loader_thread 1
+
 #define QT_FEATURE_qml_python 1
 
 
@@ -37,3 +42,5 @@
 #define QT_FEATURE_qml_jit -1
 #endif
 
+
+#endif // QT_FEATURES_Qml_src_qml_qtqml_config_p_h_H
