@@ -1,5 +1,6 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant
 #ifndef QV4IDENTIFIERTABLE_H
 #define QV4IDENTIFIERTABLE_H
 
@@ -24,7 +25,7 @@ QT_BEGIN_NAMESPACE
 
 namespace QV4 {
 
-struct Q_QML_PRIVATE_EXPORT IdentifierTable
+struct Q_QML_EXPORT IdentifierTable
 {
     ExecutionEngine *engine;
 
@@ -57,7 +58,6 @@ public:
 
     enum KeyConversionBehavior { Default, ForceConversionToId };
     PropertyKey asPropertyKey(const QString &s, KeyConversionBehavior conversionBehavior = Default);
-    PropertyKey asPropertyKey(const char *s, int len);
 
     PropertyKey asPropertyKeyImpl(const Heap::String *str);
 
