@@ -1,5 +1,6 @@
 // Copyright (C) 2021 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #ifndef QQMLCODEMODEL_P_H
 #define QQMLCODEMODEL_P_H
@@ -65,18 +66,32 @@ public:
     std::shared_ptr<Utils::TextDocument> textDocument;
 };
 
-struct ToIndex
-{
-    QString path;
-    int leftDepth;
-};
-
 struct RegisteredSemanticTokens
 {
     QByteArray resultId = "0";
     QList<int> lastTokens;
 };
 
+struct ModuleSetting
+{
+    QString sourceFolder;
+    QStringList importPaths;
+};
+
+using ModuleSettings = QList<ModuleSetting>;
+class QQmllsBuildInformation
+{
+public:
+    QQmllsBuildInformation();
+    void loadSettingsFrom(const QStringList &buildPaths);
+    QStringList importPathsFor(const QString &filePath);
+
+private:
+    QString m_docDir;
+    ModuleSettings m_moduleSettings;
+    QSet<QString> m_seenSettings;
+};
+
 class QQmlCodeModel : public QObject
 {
     Q_OBJECT
@@ -92,8 +107,6 @@ public:
     OpenDocument openDocumentByUrl(const QByteArray &url);
 
     void openNeedUpdate();
-    void indexNeedsUpdate();
-    void addDirectoriesToIndex(const QStringList &paths, QLanguageServer *server);
     void addOpenToUpdate(const QByteArray &);
     void removeDirectory(const QString &path);
     // void updateDocument(const OpenDocument &doc);
@@ -107,7 +120,7 @@ public:
     QStringList buildPathsForRootUrl(const QByteArray &url);
     QStringList buildPathsForFileUrl(const QByteArray &url);
     void setBuildPathsForRootUrl(QByteArray url, const QStringList &paths);
-    QStringList importPathsForFile(const QString &fileName) const;
+    QStringList importPathsForFile(const QString &fileName);
     QStringList importPaths() const { return m_importPaths; };
     void setImportPaths(const QStringList &paths) { m_importPaths = paths; };
     void removeRootUrls(const QList<QByteArray> &urls);
@@ -129,13 +142,6 @@ Q_SIGNALS:
     void documentationRootPathChanged(const QString &path);
 
 private:
-    void indexDirectory(const QString &path, int depthLeft);
-    int indexEvalProgress() const; // to be called in the mutex
-    void indexStart(); // to be called in the mutex
-    void indexEnd(); // to be called in the mutex
-    void indexSendProgress(int progress);
-    bool indexCancelled();
-    bool indexSome();
     void addDirectory(const QString &path, int leftDepth);
     bool openUpdateSome();
     void openUpdateStart();
@@ -149,11 +155,6 @@ private:
 
     mutable QMutex m_mutex;
     State m_state = State::Running;
-    int m_lastIndexProgress = 0;
-    int m_nIndexInProgress = 0;
-    QList<ToIndex> m_toIndex;
-    int m_indexInProgressCost = 0;
-    int m_indexDoneCost = 0;
     int m_nUpdateInProgress = 0;
     QStringList m_importPaths;
     QQmlJS::Dom::DomItem m_currentEnv;
@@ -166,6 +167,7 @@ private:
     QHash<QString, QByteArray> m_path2url;
     QHash<QByteArray, OpenDocument> m_openDocuments;
     QQmlToolingSettings *m_settings;
+    QQmllsBuildInformation m_buildInformation;
     QFileSystemWatcher m_cppFileWatcher;
     QFactoryLoader m_pluginLoader;
     bool m_rebuildRequired = true; // always trigger a rebuild on start
