@@ -4,7 +4,9 @@
 #ifndef QTQMLXMLLISTMODELEXPORTS_H
 #define QTQMLXMLLISTMODELEXPORTS_H
 
-#include <QtCore/qglobal.h>
+#include <QtCore/qcompilerdetection.h>
+#include <QtCore/qtconfigmacros.h> // Q_QMLXMLLISTMODEL_EXPORT
+#include <QtCore/qtdeprecationmarkers.h> // QT_IF_DEPRECATED_SINCE
 
 #if defined(QT_SHARED) || !defined(QT_STATIC)
 #  if defined(QT_BUILD_QMLXMLLISTMODEL_LIB)
@@ -16,24 +18,30 @@
 #  define Q_QMLXMLLISTMODEL_EXPORT
 #endif
 
-#if !defined(QT_BUILD_QMLXMLLISTMODEL_LIB) || defined(QT_STATIC)
-/* outside library → inline decl + defi */
+#if !defined(QT_BUILD_QMLXMLLISTMODEL_LIB) && !defined(QT_STATIC)
+/* outside library -> inline decl + defi */
+/* static builds treat everything as part of the library, so they never inline */
 #  define QT_QMLXMLLISTMODEL_INLINE_SINCE(major, minor) inline
+#  define QT_QMLXMLLISTMODEL_CONSTEXPR_INLINE_SINCE(major, minor) constexpr
 #  define QT_QMLXMLLISTMODEL_INLINE_IMPL_SINCE(major, minor) 1
 #elif defined(QT_QMLXMLLISTMODEL_BUILD_REMOVED_API)
 /* inside library, inside removed_api.cpp:
- * keep deprecated API → non-inline decl;
- * remove deprecated API → inline decl;
+ * keep deprecated API -> non-inline decl;
+ * remove deprecated API -> inline decl;
  * definition is always available */
 #  define QT_QMLXMLLISTMODEL_INLINE_SINCE(major, minor) \
     QT_IF_DEPRECATED_SINCE(major, minor, inline, /* not inline */)
+#  define QT_QMLXMLLISTMODEL_CONSTEXPR_INLINE_SINCE(major, minor) \
+    QT_IF_DEPRECATED_SINCE(major, minor, constexpr, /* not inline */)
 #  define QT_QMLXMLLISTMODEL_INLINE_IMPL_SINCE(major, minor) 1
 #else
 /* inside library, outside removed_api.cpp:
- * keep deprecated API → non-inline decl, no defi;
- * remove deprecated API → inline decl, defi */
+ * keep deprecated API -> non-inline decl, no defi;
+ * remove deprecated API -> inline decl, defi */
 #  define QT_QMLXMLLISTMODEL_INLINE_SINCE(major, minor) \
     QT_IF_DEPRECATED_SINCE(major, minor, inline, /* not inline */)
+#  define QT_QMLXMLLISTMODEL_CONSTEXPR_INLINE_SINCE(major, minor) \
+    QT_IF_DEPRECATED_SINCE(major, minor, constexpr, /* not inline */)
 #  define QT_QMLXMLLISTMODEL_INLINE_IMPL_SINCE(major, minor) \
     QT_IF_DEPRECATED_SINCE(major, minor, 1, 0)
 #endif
