@@ -1,5 +1,6 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #ifndef QQUICKAPPLICATION_P_H
 #define QQUICKAPPLICATION_P_H
@@ -28,7 +29,7 @@
 
 QT_BEGIN_NAMESPACE
 
-class Q_QUICK_PRIVATE_EXPORT QQuickApplication : public QQmlApplication
+class Q_QUICK_EXPORT QQuickApplication : public QQmlApplication
 {
     Q_OBJECT
     Q_PROPERTY(bool active READ active NOTIFY activeChanged FINAL) // deprecated, use 'state' instead
@@ -69,11 +70,9 @@ private Q_SLOTS:
 
 private:
     Q_DISABLE_COPY(QQuickApplication)
-    QVector<QQuickScreenInfo *> m_screens;
+    std::vector<std::unique_ptr<QQuickScreenInfo>> m_screens;
 };
 
 QT_END_NAMESPACE
 
-QML_DECLARE_TYPE(QQuickApplication)
-
 #endif // QQUICKAPPLICATION_P_H
