@@ -1,5 +1,6 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #ifndef QQUICKFONTMETRICS_H
 #define QQUICKFONTMETRICS_H
@@ -46,6 +47,7 @@ class Q_QUICK_EXPORT QQuickFontMetrics : public QObject
     Q_PROPERTY(qreal overlinePosition READ overlinePosition NOTIFY fontChanged)
     Q_PROPERTY(qreal strikeOutPosition READ strikeOutPosition NOTIFY fontChanged)
     Q_PROPERTY(qreal lineWidth READ lineWidth NOTIFY fontChanged)
+    Q_PROPERTY(qreal capitalHeight READ capitalHeight NOTIFY fontChanged REVISION (6,9))
     QML_NAMED_ELEMENT(FontMetrics)
     QML_ADDED_IN_VERSION(2, 4)
 public:
@@ -56,6 +58,7 @@ public:
 
     qreal ascent() const;
     qreal descent() const;
+    qreal capitalHeight() const;
     qreal height() const;
     qreal leading() const;
     qreal lineSpacing() const;
