@@ -1,5 +1,6 @@
 // Copyright (C) 2017 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #ifndef QQUICKCONTROL_P_P_H
 #define QQUICKCONTROL_P_P_H
@@ -35,7 +36,8 @@ Q_DECLARE_LOGGING_CATEGORY(lcItemManagement)
 
 class QQuickAccessibleAttached;
 
-class Q_QUICKTEMPLATES2_PRIVATE_EXPORT QQuickControlPrivate : public QQuickItemPrivate, public QQuickItemChangeListener
+class Q_QUICKTEMPLATES2_EXPORT QQuickControlPrivate : public QQuickItemPrivate,
+                                                      public QSafeQuickItemChangeListener<QQuickControlPrivate>
 #if QT_CONFIG(accessibility)
     , public QAccessible::ActivationObserver
 #endif
@@ -122,14 +124,22 @@ public:
     static bool calcHoverEnabled(const QQuickItem *item);
 #endif
 
+    static void warnIfCustomizationNotSupported(QObject *control, QQuickItem *item, const QString &propertyName);
+
     virtual void cancelContentItem();
     virtual void executeContentItem(bool complete = false);
 
     virtual void cancelBackground();
     virtual void executeBackground(bool complete = false);
 
+    enum class UnhideVisibility {
+        Show,
+        Hide
+    };
+
     static void hideOldItem(QQuickItem *item);
-    static void unhideOldItem(QQuickControl *control, QQuickItem *item);
+    static void unhideOldItem(QQuickControl *control, QQuickItem *item,
+        UnhideVisibility visibility = UnhideVisibility::Show);
 
     void updateBaselineOffset();
 
@@ -147,6 +157,8 @@ public:
     void itemDestroyed(QQuickItem *item) override;
     void itemFocusChanged(QQuickItem *item, Qt::FocusReason reason) override;
 
+    bool setLastFocusChangeReason(Qt::FocusReason) override;
+
     virtual qreal getContentWidth() const;
     virtual qreal getContentHeight() const;
 
@@ -198,8 +210,6 @@ public:
     qreal spacing = 0;
     QLocale locale;
     QFont resolvedFont;
-    Qt::FocusPolicy focusPolicy = Qt::NoFocus;
-    Qt::FocusReason focusReason = Qt::OtherFocusReason;
     QQuickDeferredPointer<QQuickItem> background;
     QQuickDeferredPointer<QQuickItem> contentItem;
 };
